@@ -1,5 +1,5 @@
 package Mojolicious::Plugin::AutoRoutePm;
-$Mojolicious::Plugin::AutoRoutePm::VERSION = '0.21';
+$Mojolicious::Plugin::AutoRoutePm::VERSION = '0.22';
 use Mojo::Base 'Mojolicious::Plugin';
 
 use File::Find::Rule;
@@ -59,6 +59,11 @@ sub register {
         }
     }
 
+    # sort routes so, first existing .pm module which aren't DocumentRoot
+    my @template_index  = grep /$dindex$/,  @templates;
+    my @template_nindex = grep !/$dindex$/, @templates;
+    @templates = ( @template_nindex, @template_index );
+
     # Register routes
     for my $template (@templates) {
 
@@ -84,6 +89,9 @@ sub register {
                 my $tr = $route->any( $template => [ format => 1 ] )
                   ->to( app => $ctl, action => 'route', format => undef );
                 $tr->any('/');
+
+                # and for /url_component/a/b/x
+                $tr->any('/*query');
             }
         }
     }
@@ -132,8 +140,8 @@ sub path_to_controller {
 Mojolicious::Plugin::AutoRoutePm - Mojolicious plugin to create routes by *.pm modules which are a controller
 
 =for html <p>
-    <a href="https://github.com/emilianobruni/mojolicious-plugin-autoroutepm/actions/workflows/test.yml">
-        <img alt="github workflow tests" src="https://github.com/emilianobruni/mojolicious-plugin-autoroutepm/workflows/test.yml/badge.svg">
+    <a href="https://github.com/EmilianoBruni/mojolicious-plugin-autoroutepm/actions/workflows/test.yml">
+        <img alt="github workflow tests" src="https://github.com/EmilianoBruni/mojolicious-plugin-autoroutepm/actions/workflows/test.yml/badge.svg">
     </a>
     <img alt="Top language: " src="https://img.shields.io/github/languages/top/emilianobruni/mojolicious-plugin-autoroutepm">
     <img alt="github last commit" src="https://img.shields.io/github/last-commit/emilianobruni/mojolicious-plugin-autoroutepm">
@@ -141,7 +149,7 @@ Mojolicious::Plugin::AutoRoutePm - Mojolicious plugin to create routes by *.pm m
 
 =head1 VERSION
 
-version 0.21
+version 0.22
 
 =head1 SYNOPSIS
 
